@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 The Apache Software Foundation.
+ * Copyright 2005-2009 The Apache Software Foundation.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -18,17 +18,14 @@
  * Copyright 2005 Sun Microsystems, Inc. All rights reserved.
  */
 /*
- * $Id: MarshalException.java 375655 2006-02-07 18:35:54Z mullan $
+ * $Id: MarshalException.java 793943 2009-07-14 15:33:19Z coheigea $
  */
 package javax.xml.crypto;
 
 import java.io.PrintStream;
 import java.io.PrintWriter;
-import javax.xml.crypto.dsig.Manifest;
 import javax.xml.crypto.dsig.XMLSignature;
 import javax.xml.crypto.dsig.XMLSignatureFactory;
-import javax.xml.crypto.dsig.keyinfo.KeyInfo;
-import javax.xml.crypto.dsig.keyinfo.KeyInfoFactory;
 
 /**
  * Indicates an exceptional condition that occured during the XML
