@@ -1,5 +1,5 @@
 /*
- * Copyright  1999-2004 The Apache Software Foundation.
+ * Copyright 1999-2009 The Apache Software Foundation.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -16,8 +16,6 @@
  */
 package org.apache.xml.security.algorithms.implementations;
 
-
-
 import java.security.InvalidAlgorithmParameterException;
 import java.security.InvalidKeyException;
 import java.security.Key;
@@ -38,7 +36,6 @@ import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Text;
 
-
 /**
  *
  * @author $Author: mullan $
@@ -56,11 +53,17 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
     */
    public abstract String engineGetURI();
 
+   /**
+    * Returns the output length of the hash/digest.
+    */
+   abstract int getDigestLength();
+
    /** Field _macAlgorithm */
    private Mac _macAlgorithm = null;
 
    /** Field _HMACOutputLength */
    int _HMACOutputLength = 0;
+   private boolean _HMACOutputLengthSet = false;
 
    /**
     * Method IntegrityHmacSHA1das
@@ -96,7 +99,9 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
    }
 
    public void reset() {
-	   _HMACOutputLength=0;
+       _HMACOutputLength=0;
+       _HMACOutputLengthSet = false;
+       this._macAlgorithm.reset();
    }
 
    /**
@@ -111,14 +116,18 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
            throws XMLSignatureException {
 
       try {
-         byte[] completeResult = this._macAlgorithm.doFinal();
-
-         if ((this._HMACOutputLength == 0) || (this._HMACOutputLength >= 160)) {
+         if (this._HMACOutputLengthSet && this._HMACOutputLength < getDigestLength())
+{
+            if (log.isDebugEnabled()) {
+                log.debug("HMACOutputLength must not be less than " + getDigestLength());
+            }
+            Object[] exArgs = { String.valueOf(getDigestLength()) };
+            throw new XMLSignatureException
+                ("algorithms.HMACOutputLengthMin", exArgs);
+         } else {
+            byte[] completeResult = this._macAlgorithm.doFinal();
             return MessageDigestAlgorithm.isEqual(completeResult, signature);
          }
-         byte[] stripped = IntegrityHmac.reduceBitLength(completeResult,
-                                 this._HMACOutputLength);
-         return MessageDigestAlgorithm.isEqual(stripped, signature);         
       } catch (IllegalStateException ex) {
          throw new XMLSignatureException("empty", ex);
       }
@@ -172,14 +181,16 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
    protected byte[] engineSign() throws XMLSignatureException {
 
       try {
-         byte[] completeResult = this._macAlgorithm.doFinal();
-
-         if ((this._HMACOutputLength == 0) || (this._HMACOutputLength >= 160)) {
-            return completeResult;
-         } 
-          return IntegrityHmac.reduceBitLength(completeResult,
-                                                 this._HMACOutputLength);
-         
+         if (this._HMACOutputLengthSet && this._HMACOutputLength < getDigestLength()) {
+            if (log.isDebugEnabled()) {
+                log.debug("HMACOutputLength must not be less than " + getDigestLength());
+            }
+            Object[] exArgs = { String.valueOf(getDigestLength()) };
+            throw new XMLSignatureException
+                ("algorithms.HMACOutputLengthMin", exArgs);
+         } else {
+            return this._macAlgorithm.doFinal();
+         }
       } catch (IllegalStateException ex) {
          throw new XMLSignatureException("empty", ex);
       }
@@ -357,6 +368,7 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
     */
    protected void engineSetHMACOutputLength(int HMACOutputLength) {
       this._HMACOutputLength = HMACOutputLength;
+      this._HMACOutputLengthSet = true;
    }
 
    /**
@@ -372,13 +384,13 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
          throw new IllegalArgumentException("element null");
       }
 
-             Text hmaclength =XMLUtils.selectDsNodeText(element.getFirstChild(),
-                    Constants._TAG_HMACOUTPUTLENGTH,0);               
+      Text hmaclength =XMLUtils.selectDsNodeText(element.getFirstChild(),
+         Constants._TAG_HMACOUTPUTLENGTH,0);               
 
-            if (hmaclength != null) {
-               this._HMACOutputLength = Integer.parseInt(hmaclength.getData());
-            }
-      
+      if (hmaclength != null) {
+         this._HMACOutputLength = Integer.parseInt(hmaclength.getData());
+         this._HMACOutputLengthSet = true;
+      }
    }
 
    /**
@@ -386,14 +398,13 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
     *
     * @param element
     */
-   public void engineAddContextToElement(Element element)
-           {
+   public void engineAddContextToElement(Element element) {
 
       if (element == null) {
          throw new IllegalArgumentException("null element");
       }
 
-      if (this._HMACOutputLength != 0) {
+      if (this._HMACOutputLengthSet) {
          Document doc = element.getOwnerDocument();
          Element HMElem = XMLUtils.createElementInSignatureSpace(doc,
                              Constants._TAG_HMACOUTPUTLENGTH);
@@ -411,7 +422,7 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
     * Class IntegrityHmacSHA1
     *
     * @author $Author: mullan $
-    * @version $Revision: 591445 $
+    * @version $Revision: 794013 $
     */
    public static class IntegrityHmacSHA1 extends IntegrityHmac {
 
@@ -432,13 +443,17 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
       public String engineGetURI() {
          return XMLSignature.ALGO_ID_MAC_HMAC_SHA1;
       }
+
+      int getDigestLength() {
+          return 160;
+      }
    }
 
    /**
     * Class IntegrityHmacSHA256
     *
     * @author $Author: mullan $
-    * @version $Revision: 591445 $
+    * @version $Revision: 794013 $
     */
    public static class IntegrityHmacSHA256 extends IntegrityHmac {
 
@@ -459,13 +474,17 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
       public String engineGetURI() {
          return XMLSignature.ALGO_ID_MAC_HMAC_SHA256;
       }
+
+      int getDigestLength() {
+          return 256;
+      }
    }
 
    /**
     * Class IntegrityHmacSHA384
     *
     * @author $Author: mullan $
-    * @version $Revision: 591445 $
+    * @version $Revision: 794013 $
     */
    public static class IntegrityHmacSHA384 extends IntegrityHmac {
 
@@ -486,13 +505,17 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
       public String engineGetURI() {
          return XMLSignature.ALGO_ID_MAC_HMAC_SHA384;
       }
+
+      int getDigestLength() {
+          return 384;
+      }
    }
 
    /**
     * Class IntegrityHmacSHA512
     *
     * @author $Author: mullan $
-    * @version $Revision: 591445 $
+    * @version $Revision: 794013 $
     */
    public static class IntegrityHmacSHA512 extends IntegrityHmac {
 
@@ -513,13 +536,17 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
       public String engineGetURI() {
          return XMLSignature.ALGO_ID_MAC_HMAC_SHA512;
       }
+
+      int getDigestLength() {
+          return 512;
+      }
    }
 
    /**
     * Class IntegrityHmacRIPEMD160
     *
     * @author $Author: mullan $
-    * @version $Revision: 591445 $
+    * @version $Revision: 794013 $
     */
    public static class IntegrityHmacRIPEMD160 extends IntegrityHmac {
 
@@ -540,13 +567,17 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
       public String engineGetURI() {
          return XMLSignature.ALGO_ID_MAC_HMAC_RIPEMD160;
       }
+
+      int getDigestLength() {
+          return 160;
+      }
    }
 
    /**
     * Class IntegrityHmacMD5
     *
     * @author $Author: mullan $
-    * @version $Revision: 591445 $
+    * @version $Revision: 794013 $
     */
    public static class IntegrityHmacMD5 extends IntegrityHmac {
 
@@ -567,5 +598,9 @@ public abstract class IntegrityHmac extends SignatureAlgorithmSpi {
       public String engineGetURI() {
          return XMLSignature.ALGO_ID_MAC_HMAC_NOT_RECOMMENDED_MD5;
       }
+
+      int getDigestLength() {
+          return 128;
+      }
    }
 }
