@@ -213,7 +213,7 @@ public abstract class Canonicalizer11 extends CanonicalizerBase {
 	    Attr N = (Attr) attrs.item(i);
 	    String NUri = N.getNamespaceURI();
 
-	    if (XMLNS_URI != NUri) {
+	    if (!XMLNS_URI.equals(NUri)) {
 		// It's not a namespace attr node. Add to the result and 
 		// continue.
 		result.add(N);
@@ -286,9 +286,9 @@ public abstract class Canonicalizer11 extends CanonicalizerBase {
 	    Attr N = (Attr) attrs.item(i);
 	    String NUri = N.getNamespaceURI();
        
-	    if (XMLNS_URI != NUri) {
+	    if (!XMLNS_URI.equals(NUri)) {
 		// A non namespace definition node.
-		if (XML_LANG_URI == NUri) {
+		if (XML_LANG_URI.equals(NUri)) {
 		    if (N.getLocalName().equals("id")) {
 			if (isRealVisible) {
 			    // treat xml:id like any other attribute 
@@ -337,7 +337,7 @@ public abstract class Canonicalizer11 extends CanonicalizerBase {
 		    }
 		}
 	    } else {
-    		if (isRealVisible && NName != XMLNS) {
+    		if (isRealVisible && !XMLNS.equals(NName)) {
 		    ns.removeMapping(NName);	
 		} else {
     		    ns.addMapping(NName, NValue, N);
@@ -412,17 +412,17 @@ public abstract class Canonicalizer11 extends CanonicalizerBase {
     }
    
     void handleParent(Element e, NameSpaceSymbTable ns) {
-	if (!e.hasAttributes()) {
-	    return;
-	}
+        if (!e.hasAttributes() && e.getNamespaceURI() == null) {
+            return;
+        }
 	xmlattrStack.push(-1);
 	NamedNodeMap attrs = e.getAttributes();
 	int attrsLength = attrs.getLength();
 	for (int i = 0; i < attrsLength; i++) {
 	    Attr N = (Attr) attrs.item(i);
-	    if (Constants.NamespaceSpecNS != N.getNamespaceURI()) {
+	    if (!Constants.NamespaceSpecNS.equals(N.getNamespaceURI())) {
 		// Not a namespace definition, ignore.
-		if (XML_LANG_URI == N.getNamespaceURI()) {
+	    if (!"id".equals(N.getLocalName()) && XML_LANG_URI.equals(N.getNamespaceURI())) {
 		    xmlattrStack.addXmlnsAttr(N);
 		}
 		continue;
@@ -436,6 +436,20 @@ public abstract class Canonicalizer11 extends CanonicalizerBase {
 	    }            
 	    ns.addMapping(NName,NValue,N);             
 	}
+	if (e.getNamespaceURI() != null) {
+	    String NName = e.getPrefix();
+	    String NValue = e.getNamespaceURI();
+	    String Name;
+	    if (NName == null || NName.equals("")) {
+	        NName = "xmlns";
+	        Name = "xmlns";
+	    } else {
+	        Name = "xmlns:" + NName;
+	    }
+	    Attr n = e.getOwnerDocument().createAttributeNS("http://www.w3.org/2000/xmlns/", Name);
+	    n.setValue(NValue);
+	    ns.addMapping(NName, NValue, n);
+	}
     }
 
     private static String joinURI(String baseURI, String relativeURI) 
