@@ -54,7 +54,7 @@ import org.xml.sax.SAXException;
  * Abstract base class for canonicalization algorithms.
  *
  * @author Christian Geuer-Pollmann <geuerp@apache.org>
- * @version $Revision: 792889 $
+ * @version $Revision: 1094513 $
  */
 public abstract class CanonicalizerBase extends CanonicalizerSpi {
    //Constants to be outputed, In char array form, so
@@ -557,14 +557,14 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
    	}
 
 	void handleParent(Element e,NameSpaceSymbTable ns) {
-	   if (!e.hasAttributes()) {
+	    if (!e.hasAttributes() && e.getNamespaceURI() == null) {
 				return;
 		}
 		NamedNodeMap attrs = e.getAttributes();
 		int attrsLength = attrs.getLength();
 		for (int i = 0; i < attrsLength; i++) {
 			Attr N = (Attr) attrs.item(i);
-			if (Constants.NamespaceSpecNS!=N.getNamespaceURI()) {
+			if (!Constants.NamespaceSpecNS.equals(N.getNamespaceURI())) {
 				//Not a namespace definition, ignore.
 				continue;
 			}
@@ -576,7 +576,21 @@ public abstract class CanonicalizerBase extends CanonicalizerSpi {
 					continue;
 			}            
 			ns.addMapping(NName,NValue,N);             
-		}   			
+		}   		
+		if (e.getNamespaceURI() != null) {
+		    String NName = e.getPrefix();
+		    String NValue = e.getNamespaceURI();
+		    String Name;
+		    if (NName == null || NName.equals("")) {
+		        NName = "xmlns";
+		        Name = "xmlns";
+		    } else {
+		        Name = "xmlns:" + NName;
+		    }
+		    Attr n = e.getOwnerDocument().createAttributeNS("http://www.w3.org/2000/xmlns/", Name);
+		    n.setValue(NValue);
+		    ns.addMapping(NName, NValue, n);
+		}
    }
 
 	/**
