@@ -153,7 +153,7 @@ public class XMLUtils {
 
       try {
          if (addPreamble) {
-            os.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n".getBytes());
+            os.write("<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n".getBytes("UTF-8"));
          }
 
          os.write(
@@ -227,7 +227,8 @@ public class XMLUtils {
 
 
    static  String dsPrefix=null;
-   static Map namePrefixes=new HashMap();
+   private static Map namePrefixes= java.util.Collections.synchronizedMap(new HashMap());
+
    /**
     * Creates an Element in the XML Signature specification namespace.
     *
@@ -295,7 +296,11 @@ public class XMLUtils {
     */
    public static boolean elementIsInSignatureSpace(Element element,
            String localName) {
-      return ElementProxy.checker.isNamespaceElement(element, localName, Constants.SignatureSpecNS);
+	   if(element == null){
+		   return false;
+	   }
+	   
+	   return Constants.SignatureSpecNS.equals(element.getNamespaceURI()) && element.getLocalName().equals(localName);
    }
 
    /**
@@ -308,7 +313,10 @@ public class XMLUtils {
     */
    public static boolean elementIsInEncryptionSpace(Element element,
            String localName) {
-	   return ElementProxy.checker.isNamespaceElement(element, localName, EncryptionConstants.EncryptionSpecNS);
+	   if(element == null){
+		   return false;
+	   }
+	   return EncryptionConstants.EncryptionSpecNS.equals(element.getNamespaceURI()) && element.getLocalName().equals(localName);
    }
 
    /**
@@ -496,7 +504,7 @@ public class XMLUtils {
 
              	for (int i = 0; i < attributesLength; i++) {
              		Attr currentAttr = (Attr) attributes.item(i); 
-             		if (namespaceNs!=currentAttr.getNamespaceURI())
+             		if (!namespaceNs.equals(currentAttr.getNamespaceURI()))
              			continue;
              		if (childElement.hasAttributeNS(namespaceNs,
     							currentAttr.getLocalName())) {
@@ -537,7 +545,7 @@ public class XMLUtils {
     */
    public static Element selectDsNode(Node sibling, String nodeName, int number) {
 	while (sibling!=null) {
-		if (ElementProxy.checker.isNamespaceElement(sibling, nodeName, Constants.SignatureSpecNS )) {
+		if (Constants.SignatureSpecNS.equals(sibling.getNamespaceURI()) && sibling.getLocalName().equals(nodeName)) {
 			if (number==0){
 				return (Element)sibling;
 			}
@@ -557,7 +565,7 @@ public class XMLUtils {
 
    public static Element selectXencNode(Node sibling, String nodeName, int number) {
 	while (sibling!=null) {
-		if (ElementProxy.checker.isNamespaceElement(sibling, nodeName, EncryptionConstants.EncryptionSpecNS )) {
+		if (EncryptionConstants.EncryptionSpecNS.equals(sibling.getNamespaceURI()) && sibling.getLocalName().equals(nodeName)) {
 			if (number==0){
 				return (Element)sibling;
 			}
@@ -615,7 +623,7 @@ public class XMLUtils {
     */
    public static Element selectNode(Node sibling, String uri,String nodeName, int number) {
 	while (sibling!=null) {
-		if (ElementProxy.checker.isNamespaceElement(sibling, nodeName, uri)) {
+		if (sibling.getNamespaceURI() != null && sibling.getNamespaceURI().equals(uri) && sibling.getLocalName().equals(nodeName)) {
 			if (number==0){
 				return (Element)sibling;
 			}
@@ -646,7 +654,7 @@ public class XMLUtils {
     	int curr=0;
     	//List list=new ArrayList();
     	while (sibling!=null) {
-    		if (ElementProxy.checker.isNamespaceElement(sibling, nodeName, uri)) {
+    		if (sibling.getNamespaceURI() != null && sibling.getNamespaceURI().equals(uri) && sibling.getLocalName().equals(nodeName)) {
     			a[curr++]=(Element)sibling;
     			if (size<=curr) {
     				int cursize= size<<2;
