@@ -49,7 +49,7 @@ import org.w3c.dom.Attr;
  * </PRE>
  *
  *
- * @author $Author: mullan $
+ * @author $Author: coheigea $
  * @see <A HREF="http://www.javaworld.com/javaworld/javatips/jw-javatip42_p.html">Java Tip 42: Write Java apps that work with proxy-based firewalls</A>
  * @see <A HREF="http://java.sun.com/j2se/1.4/docs/guide/net/properties.html">SUN J2SE docs for network properties</A>
  * @see <A HREF="http://metalab.unc.edu/javafaq/javafaq.html#proxy">The JAVA FAQ Question 9.5: How do I make Java work with a proxy server?</A>
@@ -161,7 +161,7 @@ public class ResolverDirectHTTP extends ResourceResolverSpi {
 
             if ((proxyUser != null) && (proxyPass != null)) {
                String password = proxyUser + ":" + proxyPass;
-               String encodedPassword = Base64.encode(password.getBytes());
+               String encodedPassword = Base64.encode(password.getBytes("ISO-8859-1"));
 
                // or was it Proxy-Authenticate ?
                urlConnection.setRequestProperty("Proxy-Authorization",
@@ -190,7 +190,7 @@ public class ResolverDirectHTTP extends ResourceResolverSpi {
 
                      String password = user + ":" + pass;
                      String encodedPassword =
-                        Base64.encode(password.getBytes());
+                        Base64.encode(password.getBytes("ISO-8859-1"));
 
                      // set authentication property in the http header
                      urlConnection.setRequestProperty("Authorization",
