@@ -25,7 +25,7 @@
  * ===========================================================================
  */
 /*
- * $Id: DOMReference.java 647272 2008-04-11 19:22:21Z mullan $
+ * $Id: DOMReference.java 695520 2008-09-15 16:05:09Z mullan $
  */
 package org.jcp.xml.dsig.internal.dom;
 
@@ -68,14 +68,13 @@ public final class DOMReference extends DOMStructure
     *
     * If true, overrides the same property if set in the XMLSignContext.
     */
-    private static boolean useC14N11 = false;
-    static {
-	try {
-            useC14N11 = Boolean.getBoolean("org.apache.xml.security.useC14N11");
-        } catch (Exception e) {
-            // ignore exceptions
-       }
-    }
+    private static boolean useC14N11 = ((Boolean)
+        AccessController.doPrivileged(new PrivilegedAction() {
+            public Object run() {
+                return Boolean.valueOf(Boolean.getBoolean
+                    ("com.sun.org.apache.xml.internal.security.useC14N11"));
+            }
+        })).booleanValue();
 
     private static Logger log = Logger.getLogger("org.jcp.xml.dsig.internal.dom");
 
@@ -479,7 +478,15 @@ public final class DOMReference extends DOMStructure
                 this.dis = dos.getInputStream();
             }
             return dos.getDigestValue();
-	} catch (Exception e) {
+	} catch (NoSuchAlgorithmException e) {
+	    throw new XMLSignatureException(e);
+	} catch (TransformException e) {
+	    throw new XMLSignatureException(e);
+	} catch (MarshalException e) {
+	    throw new XMLSignatureException(e);
+	} catch (IOException e) {
+	    throw new XMLSignatureException(e);
+	} catch (org.apache.xml.security.c14n.CanonicalizationException e) {
 	    throw new XMLSignatureException(e);
 	}
     }
@@ -507,8 +514,9 @@ public final class DOMReference extends DOMStructure
 	boolean digestValuesEqual = 
 	    Arrays.equals(digestValue, oref.getDigestValue());
 
-	return (digestMethod.equals(oref.getDigestMethod()) && idsEqual &&
-	    urisEqual && typesEqual && allTransforms.equals(oref.getTransforms()));
+	return digestMethod.equals(oref.getDigestMethod()) && idsEqual &&
+	    urisEqual && typesEqual && 
+            allTransforms.equals(oref.getTransforms()) && digestValuesEqual;
     }
 
     public int hashCode() {
