@@ -1,5 +1,5 @@
 /*
- * Copyright 2005 The Apache Software Foundation.
+ * Copyright 2005-2009 The Apache Software Foundation.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@
  * Copyright 2005 Sun Microsystems, Inc. All rights reserved.
  */
 /*
- * $Id: DOMSignedInfo.java 647272 2008-04-11 19:22:21Z mullan $
+ * $Id: DOMSignedInfo.java 793943 2009-07-14 15:33:19Z coheigea $
  */
 package org.jcp.xml.dsig.internal.dom;
 
@@ -30,7 +30,6 @@ import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.InputStream;
 import java.io.IOException;
-import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.security.Provider;
 import java.util.*;
@@ -42,7 +41,6 @@ import org.w3c.dom.Node;
 
 import org.apache.xml.security.utils.Base64;
 import org.apache.xml.security.utils.UnsyncBufferedOutputStream;
-import org.apache.xml.security.utils.XMLUtils;
 
 /**
  * DOM-based implementation of SignedInfo.
@@ -186,7 +184,7 @@ public final class DOMSignedInfo extends DOMStructure implements SignedInfo {
 	DOMSubTreeData subTree = new DOMSubTreeData(localSiElem, true);
 
 	try {
-	    Data data = ((DOMCanonicalizationMethod) 
+	    ((DOMCanonicalizationMethod) 
 		canonicalizationMethod).canonicalize(subTree, context, os);
 	} catch (TransformException te) {
 	    throw new XMLSignatureException(te);
@@ -196,16 +194,12 @@ public final class DOMSignedInfo extends DOMStructure implements SignedInfo {
 
         // this whole block should only be done if logging is enabled
 	if (log.isLoggable(Level.FINE)) {
-            InputStreamReader isr = new InputStreamReader
-		(new ByteArrayInputStream(signedInfoBytes));
-            char[] siBytes = new char[signedInfoBytes.length];
-            try {
-                isr.read(siBytes);
-                log.log(Level.FINE, "Canonicalized SignedInfo:\n" 
-		    + new String(siBytes));
-            } catch (IOException ioex) {
-		log.log(Level.FINE, "IOException reading SignedInfo bytes");
-	    } 
+            log.log(Level.FINE, "Canonicalized SignedInfo:"); 
+            StringBuffer sb = new StringBuffer(signedInfoBytes.length);
+            for (int i = 0; i < signedInfoBytes.length; i++) {
+                sb.append((char) signedInfoBytes[i]);
+            }
+            log.log(Level.FINE, sb.toString());
 	    log.log(Level.FINE, "Data to be signed/verified:"
                 + Base64.encode(signedInfoBytes));
 	}
