@@ -25,7 +25,7 @@
  * Portions copyright 2005 Sun Microsystems, Inc. All rights reserved.
  */
 /*
- * $Id: XMLDSigRI.java 630988 2008-02-25 20:55:47Z mullan $
+ * $Id: XMLDSigRI.java 1042994 2010-12-07 12:08:24Z coheigea $
  */
 package org.jcp.xml.dsig.internal.dom;
 
@@ -48,12 +48,12 @@ public final class XMLDSigRI extends Provider {
 
     static final long serialVersionUID = -5049765099299494554L;
 
-    private static final String INFO = "XMLDSig " + 
-    "(DOM XMLSignatureFactory; DOM KeyInfoFactory)";
+    private static final String INFO = "Apache Santuario XMLDSig " + 
+        "(DOM XMLSignatureFactory; DOM KeyInfoFactory)";
 
     public XMLDSigRI() {
 	/* We are the XMLDSig provider */
-	super("XMLDSig", 1.0, INFO);
+	super("XMLDSig", 1.45, INFO);
 	
 	final Map map = new HashMap();
         map.put("XMLSignatureFactory.DOM", 
