@@ -52,7 +52,7 @@ import org.w3c.dom.Node;
 
 /**
  *
- * @author $Author: blautenb $
+ * @author $Author: mullan $
  */
 public class CreateMerlinsExampleTwentyThree {
     
@@ -67,7 +67,7 @@ public class CreateMerlinsExampleTwentyThree {
     * @throws Exception
     */
    public static void main(String unused[]) throws Exception {
-      Constants.setSignatureSpecNSprefix("");
+      Constants.setSignatureSpecNSprefix("ds");
       //J-
       String keystoreType = "JKS";
       String keystoreFile = "data/org/apache/xml/security/samples/input/keystore.jks";
