@@ -1,5 +1,5 @@
 /*
- * Copyright  2004 The Apache Software Foundation.
+ * Copyright  2004-2010 The Apache Software Foundation.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -48,7 +48,9 @@ public class ModuleTest extends TestCase {
       suite.addTest(org.apache.xml.security.test.c14n.implementations.Canonicalizer20010315Test.suite());
       suite.addTest(org.apache.xml.security.test.c14n.implementations.Canonicalizer20010315ExclusiveTest.suite());
       suite.addTest(org.apache.xml.security.test.c14n.implementations.ExclusiveC14NInterop.suite());
+      suite.addTest(org.apache.xml.security.test.c14n.implementations.Canonicalizer11Test.suite());
       suite.addTest(org.apache.xml.security.test.c14n.implementations.Bug45961Test.suite());
+      suite.addTest(org.apache.xml.security.test.c14n.implementations.Santuario191Test.suite());
       suite.addTest(org.apache.xml.security.test.external.org.apache.xalan.XPathAPI.XalanBug1425Test.suite());
       suite.addTest(org.apache.xml.security.test.external.org.apache.xalan.XPathAPI.AttributeAncestorOrSelfTest.suite());
       suite.addTest(org.apache.xml.security.test.signature.AllTests.suite());      
@@ -57,9 +59,13 @@ public class ModuleTest extends TestCase {
       suite.addTest(org.apache.xml.security.test.transforms.implementations.AllTests.suite());
       suite.addTest(org.apache.xml.security.test.transforms.RegisterTest.suite());
       suite.addTest(org.apache.xml.security.test.algorithms.AllTests.suite());
+      suite.addTest(org.apache.xml.security.test.keys.keyresolver.KeyResolverTest.suite());
       suite.addTest(org.apache.xml.security.test.keys.content.x509.XMLX509SKITest.suite());
       suite.addTest(org.apache.xml.security.test.keys.content.x509.XMLX509IssuerSerialTest.suite());
       suite.addTest(org.apache.xml.security.test.keys.content.x509.XMLX509CertificateTest.suite());
+      suite.addTest(org.apache.xml.security.test.keys.storage.KeyStoreResolverTest.suite());
+      suite.addTest(org.apache.xml.security.test.keys.storage.StorageResolverTest.suite());
+      suite.addTest(org.apache.xml.security.test.version.VersionTest.suite());
       // suite.addTest(org.apache.xml.security.test.algorithms.implementations.KeyWrapTest.suite());
       // suite.addTest(org.apache.xml.security.test.algorithms.implementations.BlockEncryptionTest.suite());
       //J+
