@@ -1,5 +1,5 @@
 /*
- * Copyright 1999-2004 The Apache Software Foundation.
+ * Copyright 1999-2009 The Apache Software Foundation.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -25,18 +25,16 @@ import java.security.cert.X509Certificate;
 import junit.framework.TestCase;
 
 import org.apache.xml.security.keys.KeyInfo;
-import org.apache.xml.security.signature.Reference;
 import org.apache.xml.security.signature.XMLSignature;
 import org.apache.xml.security.test.TestUtils;
 import org.apache.xml.security.utils.Constants;
-import org.apache.xml.security.utils.JavaUtils;
 import org.apache.xml.security.utils.resolver.ResourceResolverSpi;
 import org.apache.xpath.XPathAPI;
 import org.w3c.dom.Element;
 
 /**
  *
- * @author $Author: raul $
+ * @author $Author: coheigea $
  */
 
 
@@ -147,8 +145,6 @@ public class InteropTest extends TestCase {
          throw new RuntimeException("Did not find a KeyInfo");
       }
       if (!result) {
-    	  StringBuffer sb = new StringBuffer();
-
           for (int i = 0; i < signature.getSignedInfo().getLength(); i++) {
              boolean refVerify =
                 signature.getSignedInfo().getVerificationResult(i);             
@@ -156,11 +152,8 @@ public class InteropTest extends TestCase {
              if (refVerify) {
                 log.debug("Reference " + i + " was OK");
              } else {
-                sb.append(i + " ");
-                JavaUtils.writeBytesToFilename(filename + i + ".apache.txt", signature.getSignedInfo().item(i).getContentsAfterTransformation().getBytes());                
-                
-                
-                log.debug("Reference " + i );
+                // JavaUtils.writeBytesToFilename(filename + i + ".apache.txt", signature.getSignedInfo().item(i).getContentsAfterTransformation().getBytes());                
+                log.debug("Reference " + i + " was not OK");
              }
           }
           //throw new RuntimeException("Falle:"+sb.toString());
