@@ -1,5 +1,5 @@
 /*
- * Copyright 2009 The Apache Software Foundation.
+ * Copyright 2009-2010 The Apache Software Foundation.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -47,7 +47,8 @@ public class InvalidKeyTest extends TestCase {
        return new TestSuite(InvalidKeyTest.class);
     }
 
-    private static final String BASEDIR = System.getProperty("basedir");
+    private static final String BASEDIR = 
+        System.getProperty("basedir") == null ? "./": System.getProperty("basedir");
     private static final String SEP = System.getProperty("file.separator");
 
     public void test() throws Exception {
